
gaussiancl
==========

**angular power spectra transformation for Gaussian random fields**

This is a minimal Python package for working with the angular power spectra of
spherical random fields constructed by transforming Gaussian random fields.

It can solve for the Gaussian angular power spectrum that will yield a given
target angular power spectrum under a given transformation, such as lognormal.

The package can be installed using pip:

    pip install gaussiancl

Then import the `gaussiancl` function from the package:

    from gaussiancl import gaussiancl

For more information, please see the [documentation].

Current functionality covers the absolutely minimal use case.  Please open an
issue on GitHub if you would like to see anything added.

[documentation]: https://cltools.readthedocs.io/gaussiancl/
